@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2018-2022 Univention GmbH
+# Copyright 2018-2023 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -30,24 +30,24 @@
 # <https://www.gnu.org/licenses/>.
 
 
-import univention.portal.config as config
+from univention.portal import config
 
 
 class User(object):
-	def __init__(self, username, display_name, groups, headers):
-		self.username = username
-		self.display_name = display_name
-		self.groups = [group.lower() for group in groups]
-		self.headers = headers
+    def __init__(self, username, display_name, groups, headers):
+        self.username = username
+        self.display_name = display_name
+        self.groups = [group.lower() for group in groups]
+        self.headers = headers
 
-	def is_admin(self):
-		if self.is_anonymous():
-			return False
-		admin_groups = config.fetch("admin_groups")
-		return any(self.is_member_of(group) for group in admin_groups)
+    def is_admin(self):
+        if self.is_anonymous():
+            return False
+        admin_groups = config.fetch("admin_groups")
+        return any(self.is_member_of(group) for group in admin_groups)
 
-	def is_anonymous(self):
-		return self.username is None
+    def is_anonymous(self):
+        return self.username is None
 
-	def is_member_of(self, group):
-		return group.lower() in self.groups
+    def is_member_of(self, group):
+        return group.lower() in self.groups
